five.customerize
================

Overview
--------

``five.customerize`` is an add-on for the Zope Applicationserver.
It provides the ability to customize Page-Template-based browser-views through the web.

It was created to replace the old CMF's portal_skin tools,
where it is possible to customize old-style file-system based page templates.

Developer Resources
-------------------

- `Source Code <https://github.com/zopefoundation/five.customerize>`_
- `Issue Tracker <https://github.com/zopefoundation/five.customerize/issues>`_

License
-------

This code is publsihed under the Zope Public License (ZPL) Version 2.1

The license is included in the `LICENSE.txt` file.
